

set -ex



pushd tests
pushd prefix-replacement
test -f ${PREFIX}/lib/libpython${PKG_VERSION%.*}.a
test -f ${PREFIX}/lib/libpython${PKG_VERSION%.*}.nolto.a
test -f ${PREFIX}/lib/python${PKG_VERSION%.*}/config-${PKG_VERSION%.*}-darwin/libpython${PKG_VERSION%.*}.a
bash build-and-test.sh
popd
popd
exit 0
